#!/usr/bin/python
import sys
import subprocess
from pathlib import Path
from PIL import Image
from PIL.ExifTags import TAGS

def get_image_info(path):
    img = Image.open(path)
    width, height = img.size

    exif = get_exif(img)

    ori = exif['Orientation']
    
    return(width, height, ori)

def get_exif(img):
    try:
        exif = img._getexif()
    except AttributeError:
        return {'Orientation':1}

    if exif == None:
        return {'Orientation':1}
    
    exif_table = {}
    for tag_id, value in exif.items():
        tag = TAGS.get(tag_id, tag_id)
        exif_table[tag] = value

    return exif_table

def add_margin_resize_img(in_path, w, h, out_path):
    new_w = round(float(h) * 16.0 / 9.0)
    cmd = 'c:/usr/ImageMagick/convert.exe {} -background black -gravity center -extent {}x{} -strip -resize 1280x720 {}'.format(in_path, new_w, h, out_path)
    print(cmd)
    subprocess.call(cmd, shell=True)

def resize_img(in_path, w, h, out_path):
    cmd = 'c:/usr/ImageMagick/convert.exe {} -strip -resize 1280x720 {}'.format(in_path, out_path)
    print(cmd)
    subprocess.call(cmd, shell=True)

def flip_and_resize_img(in_path, w, h, out_path):
    new_w = round(float(w) * 16.0 / 9.0)
    cmd = 'c:/usr/ImageMagick/convert.exe {} -background black -gravity center -extent {}x{} -strip -rotate 90 -resize 1280x720 {}'.format(in_path, w, new_w, out_path)
    print(cmd)
    subprocess.call(cmd, shell=True)

def check_image(w, h):
    if w < h:
        print('Height is longer than width.', file=sys.stderr)
        return False
    
    aspect_ratio = float(w) / float(h)
    if aspect_ratio < 1.77 or aspect_ratio > 1.78:
        print('Aspect ratio is not 16:9', file=sys.stderr)
        return False
    
    return True

def main(arg_dir_in, arg_dir_out):
    dir_in = Path(arg_dir_in)
    dir_out = Path(arg_dir_out)

    for file in dir_in.glob('*.[Jj][Pp][Gg]'):
        in_img_path = dir_in / file.name
        out_img_path = dir_out / file.name
        w, h, ori = get_image_info(in_img_path)

        #print('{}:{}, {} ({})'.format(in_img_path, w, h, ori))

        if ori == 0:
            add_margin_resize_img(in_img_path, w, h, out_img_path)
        elif ori == 1:
            if check_image(w, h) == True:
                resize_img(in_img_path, w, h, out_img_path)
        elif ori ==6:
            flip_and_resize_img(in_img_path, w, h, out_img_path)
        else:
            print('Unknown EXIF orientation: {}\n'.format(ori), file=sys.stderr)
            sys.exit(1)

if __name__ == "__main__":
    main(sys.argv[1], sys.argv[2])
